api.datastores.v1.store package — Argus-Toolbelt 1.0 documentation

# api.datastores.v1.store package

## Submodules

## api.datastores.v1.store.store module

Autogenerated API

`api.datastores.v1.store.store.` `delete_data_store_entries`(dataStore: str, key: list = None, customerID: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Deletes the specified datastore entries for the specified store. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name key (list) – Datastore keys to delete customerID (int) – Specify datastore to delete entries from (default is users customer)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 973, “limit”: 116, “responseCode”: 200, “count”: 181, “data”: [{“dataStoreName”: “Require discuss outside family first.”, “lastUpdatedTimestamp”: 149334997, “lastUpdatedByUser”: {“id”: 573, “customerID”: 699, “userName”: “stevenjones”, “name”: “Sarah Lee”}, “key”: “Bed late study responsibility last wish box.”, “value”: “Although above marriage.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Audience attention compare college respond tell.”, “messageTemplate”: “Next event young pull system threat run.”, “field”: “Say discussion everybody deep.”, “parameter”: {}, “timestamp”: 907234967}], “currentPage”: 395, “size”: 215}

`api.datastores.v1.store.store.` `get_entries_from_store`(dataStore: str, limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, userID: list = None, key: list = None, fromKey: str = None, toKey: str = None, startTimestamp: int = None, endTimestamp: int = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns datastore entries for the specified store, matching the search criteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. userID (list) – Restrict search to entries which was last updated by specified users. key (list) – Restrict search to the specified key (entries). fromKey (str) – Restrict search to entries (map keys) which are greater than this key (including, by lexical order). toKey (str) – Restrict search to entries (map keys) which are less than this key (including, by lexical order). startTimestamp (int) – Restrict search to entries which are last updated after this timestamp (including). endTimestamp (int) – Restrict search to entries which are last updated before this timestamp (including). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 387, “limit”: 61, “responseCode”: 200, “count”: 628, “data”: [{“dataStoreName”: “Anyone would approach money.”, “lastUpdatedTimestamp”: 1241441595, “lastUpdatedByUser”: {“id”: 579, “customerID”: 71, “userName”: “richard25”, “name”: “Karina Avery”}, “key”: “Mother apply local whether network.”, “value”: “Finish nice billion large plant.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Staff grow purpose name even.”, “messageTemplate”: “Morning small help require hit.”, “field”: “Effort fear include machine risk represent outside.”, “parameter”: {}, “timestamp”: 574014704}], “currentPage”: 348, “size”: 617}

`api.datastores.v1.store.store.` `get_entries_from_store_simplified`(dataStore: str, customerID: list = None, key: list = None, offset: int = 0, limit: int = 25, includeDeleted: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns datastore entries for the specified store, matching query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name customerID (list) – Limit search to entries for the specified customers key (list) – Limit search to the specified entry keys offset (int) – Skip a number of results limit (int) – Maximum number of returned results includeDeleted (bool) – Include deleted/expired keys
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 716, “limit”: 60, “responseCode”: 200, “count”: 177, “data”: [{“dataStoreName”: “Republican society site no recent receive military.”, “lastUpdatedTimestamp”: 480243691, “lastUpdatedByUser”: {“id”: 768, “customerID”: 397, “userName”: “rogermoreno”, “name”: “Matthew Harris”}, “key”: “He operation customer state.”, “value”: “Risk it animal chance base somebody not.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Mean relationship during nature.”, “messageTemplate”: “Officer race glass special.”, “field”: “Civil hair necessary other move goal produce number.”, “parameter”: {}, “timestamp”: 1085597225}], “currentPage”: 853, “size”: 961}

`api.datastores.v1.store.store.` `get_single_entry`(dataStore: str, key: str, customerID: int = None, includeDeleted: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns the specified datastore entry for the specified store, or null if it does not exist (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name key (str) – Key to search customerID (int) – Search specified customer store for this key (default is users customer) includeDeleted (bool) – Include deleted/expired key
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 893, “limit”: 196, “responseCode”: 200, “count”: 764, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Field fear both woman away.”, “messageTemplate”: “Similar Mr green class sell.”, “field”: “Front sign drive me floor baby thing.”, “parameter”: {}, “timestamp”: 376632086}], “currentPage”: 960, “size”: 257}

`api.datastores.v1.store.store.` `put_data_store_entries`(dataStore: str, customerID: int = None, entries: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates the provided datastore entries for the specified store. (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name customerID (int) – ID of customer to bind data to. If not set, default is to bind to the current users customer (or none, if datastore is global) entries (list) – Entries to add
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 324, “limit”: 195, “responseCode”: 200, “count”: 101, “data”: [{“dataStoreName”: “Cell feeling street step.”, “lastUpdatedTimestamp”: 533776117, “lastUpdatedByUser”: {“id”: 338, “customerID”: 111, “userName”: “cvaldez”, “name”: “Jesse Smith”}, “key”: “Concern sit newspaper quickly impact cause any heart.”, “value”: “Hundred red road call mind ok political view.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hit far animal across.”, “messageTemplate”: “Computer very difficult everybody full.”, “field”: “Today picture recent both there agency.”, “parameter”: {}, “timestamp”: 901042070}], “currentPage”: 883, “size”: 632}

`api.datastores.v1.store.store.` `put_single_data_store_entry`(dataStore: str, key: str, customerID: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds the provided datastore entry for the specified store. To use for lists (key, no value) (PUBLIC)

  Return type: | `dict`
  Parameters: | dataStore (str) – Store name key (str) – Datastore key to set customerID (int) – Specify datastore to put entry to (default is users customer)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 StoreNotFoundException – on 404
  Returns: | {“offset”: 734, “limit”: 403, “responseCode”: 200, “count”: 785, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Follow light goal claim relate face other staff.”, “messageTemplate”: “Bank safe treat whether from sell.”, “field”: “Whose hard throughout beat war offer no rate.”, “parameter”: {}, “timestamp”: 509730153}], “currentPage”: 568, “size”: 89}

## Module contents